@@ -1,4 +1,4 @@
 module, require("react"), define, define.amd, define([
     "exports",
     "react"
-], null);
+], ha);
